<div class="clt">
<ul><li>
<a href="vcd">vcd</a><ul><li>
<a href="vcd_catalog">catalog</a><ul><li>
<a href="vcd_catalog_acl">acl</a><ul><li>
<a href="vcd_catalog_acl_add">add</a></li><li>
<a href="vcd_catalog_acl_list">list</a></li><li>
<a href="vcd_catalog_acl_remove">remove</a></li><li>
<a href="vcd_catalog_acl_share">share</a></li><li>
<a href="vcd_catalog_acl_unshare">unshare</a></li>
</ul></li>
<li>
<a href="vcd_catalog_change-owner">change-owner</a></li><li>
<a href="vcd_catalog_create">create</a></li><li>
<a href="vcd_catalog_delete">delete</a></li><li>
<a href="vcd_catalog_download">download</a></li><li>
<a href="vcd_catalog_info">info</a></li><li>
<a href="vcd_catalog_list">list</a></li><li>
<a href="vcd_catalog_share">share</a></li><li>
<a href="vcd_catalog_unshare">unshare</a></li><li>
<a href="vcd_catalog_update">update</a></li><li>
<a href="vcd_catalog_upload">upload</a></li>
</ul></li>
<li>
<a href="vcd_disk">disk</a><ul><li>
<a href="vcd_disk_change-owner">change-owner</a></li><li>
<a href="vcd_disk_create">create</a></li><li>
<a href="vcd_disk_delete">delete</a></li><li>
<a href="vcd_disk_info">info</a></li><li>
<a href="vcd_disk_list">list</a></li><li>
<a href="vcd_disk_update">update</a></li>
</ul></li>
<li>
<a href="vcd_gateway">gateway</a><ul><li>
<a href="vcd_gateway_configure-default-gateway">configure-default-gateway</a><ul><li>
<a href="vcd_gateway_configure-default-gateway_enable-dns-relay">enable-dns-relay</a></li><li>
<a href="vcd_gateway_configure-default-gateway_list">list</a></li><li>
<a href="vcd_gateway_configure-default-gateway_update">update</a></li>
</ul></li>
<li>
<a href="vcd_gateway_configure-external-network">configure-external-network</a><ul><li>
<a href="vcd_gateway_configure-external-network_add">add</a></li><li>
<a href="vcd_gateway_configure-external-network_remove">remove</a></li>
</ul></li>
<li>
<a href="vcd_gateway_configure-ip-settings">configure-ip-settings</a></li><li>
<a href="vcd_gateway_configure-rate-limits">configure-rate-limits</a><ul><li>
<a href="vcd_gateway_configure-rate-limits_disable">disable</a></li><li>
<a href="vcd_gateway_configure-rate-limits_list">list</a></li><li>
<a href="vcd_gateway_configure-rate-limits_update">update</a></li>
</ul></li>
<li>
<a href="vcd_gateway_convert-to-advanced">convert-to-advanced</a></li><li>
<a href="vcd_gateway_create">create</a></li><li>
<a href="vcd_gateway_delete">delete</a></li><li>
<a href="vcd_gateway_enable-distributed-routing">enable-distributed-routing</a></li><li>
<a href="vcd_gateway_info">info</a></li><li>
<a href="vcd_gateway_list">list</a></li><li>
<a href="vcd_gateway_list-config-ip-settings">list-config-ip-settings</a></li><li>
<a href="vcd_gateway_list-syslog-server">list-syslog-server</a></li><li>
<a href="vcd_gateway_modify-form-factor">modify-form-factor</a></li><li>
<a href="vcd_gateway_redeploy">redeploy</a></li><li>
<a href="vcd_gateway_services">services</a><ul><li>
<a href="vcd_gateway_services_ca-certificate">ca-certificate</a><ul><li>
<a href="vcd_gateway_services_ca-certificate_add">add</a></li><li>
<a href="vcd_gateway_services_ca-certificate_delete">delete</a></li><li>
<a href="vcd_gateway_services_ca-certificate_list">list</a></li>
</ul></li>
<li>
<a href="vcd_gateway_services_crl-certificate">crl-certificate</a><ul><li>
<a href="vcd_gateway_services_crl-certificate_add">add</a></li><li>
<a href="vcd_gateway_services_crl-certificate_delete">delete</a></li><li>
<a href="vcd_gateway_services_crl-certificate_list">list</a></li>
</ul></li>
<li>
<a href="vcd_gateway_services_dhcp-pool">dhcp-pool</a><ul><li>
<a href="vcd_gateway_services_dhcp-pool_create">create</a></li><li>
<a href="vcd_gateway_services_dhcp-pool_delete">delete</a></li><li>
<a href="vcd_gateway_services_dhcp-pool_info">info</a></li><li>
<a href="vcd_gateway_services_dhcp-pool_list">list</a></li>
</ul></li>
<li>
<a href="vcd_gateway_services_firewall">firewall</a><ul><li>
<a href="vcd_gateway_services_firewall_create">create</a></li><li>
<a href="vcd_gateway_services_firewall_delete">delete</a></li><li>
<a href="vcd_gateway_services_firewall_delete-destination">delete-destination</a></li><li>
<a href="vcd_gateway_services_firewall_delete-service">delete-service</a></li><li>
<a href="vcd_gateway_services_firewall_delete-source">delete-source</a></li><li>
<a href="vcd_gateway_services_firewall_disable">disable</a></li><li>
<a href="vcd_gateway_services_firewall_enable">enable</a></li><li>
<a href="vcd_gateway_services_firewall_info">info</a></li><li>
<a href="vcd_gateway_services_firewall_list">list</a></li><li>
<a href="vcd_gateway_services_firewall_list-destination">list-destination</a></li><li>
<a href="vcd_gateway_services_firewall_list-object-types">list-object-types</a></li><li>
<a href="vcd_gateway_services_firewall_list-objects">list-objects</a></li><li>
<a href="vcd_gateway_services_firewall_list-service">list-service</a></li><li>
<a href="vcd_gateway_services_firewall_list-source">list-source</a></li><li>
<a href="vcd_gateway_services_firewall_reorder">reorder</a></li><li>
<a href="vcd_gateway_services_firewall_update">update</a></li>
</ul></li>
<li>
<a href="vcd_gateway_services_ipsec-vpn">ipsec-vpn</a><ul><li>
<a href="vcd_gateway_services_ipsec-vpn_change-shared-key">change-shared-key</a></li><li>
<a href="vcd_gateway_services_ipsec-vpn_create">create</a></li><li>
<a href="vcd_gateway_services_ipsec-vpn_delete">delete</a></li><li>
<a href="vcd_gateway_services_ipsec-vpn_enable-activation-status">enable-activation-status</a></li><li>
<a href="vcd_gateway_services_ipsec-vpn_enable-logging">enable-logging</a></li><li>
<a href="vcd_gateway_services_ipsec-vpn_info">info</a></li><li>
<a href="vcd_gateway_services_ipsec-vpn_info-activation-status">info-activation-status</a></li><li>
<a href="vcd_gateway_services_ipsec-vpn_info-logging-settings">info-logging-settings</a></li><li>
<a href="vcd_gateway_services_ipsec-vpn_list">list</a></li><li>
<a href="vcd_gateway_services_ipsec-vpn_set-log-level">set-log-level</a></li><li>
<a href="vcd_gateway_services_ipsec-vpn_update">update</a></li>
</ul></li>
<li>
<a href="vcd_gateway_services_nat">nat</a><ul><li>
<a href="vcd_gateway_services_nat_create-dnat">create-dnat</a></li><li>
<a href="vcd_gateway_services_nat_create-snat">create-snat</a></li><li>
<a href="vcd_gateway_services_nat_delete">delete</a></li><li>
<a href="vcd_gateway_services_nat_info">info</a></li><li>
<a href="vcd_gateway_services_nat_list">list</a></li><li>
<a href="vcd_gateway_services_nat_reorder">reorder</a></li><li>
<a href="vcd_gateway_services_nat_update-dnat">update-dnat</a></li><li>
<a href="vcd_gateway_services_nat_update-snat">update-snat</a></li>
</ul></li>
<li>
<a href="vcd_gateway_services_service-certificate">service-certificate</a><ul><li>
<a href="vcd_gateway_services_service-certificate_add">add</a></li><li>
<a href="vcd_gateway_services_service-certificate_delete">delete</a></li><li>
<a href="vcd_gateway_services_service-certificate_list">list</a></li>
</ul></li>
<li>
<a href="vcd_gateway_services_static-route">static-route</a><ul><li>
<a href="vcd_gateway_services_static-route_create">create</a></li><li>
<a href="vcd_gateway_services_static-route_delete">delete</a></li><li>
<a href="vcd_gateway_services_static-route_list">list</a></li><li>
<a href="vcd_gateway_services_static-route_update">update</a></li>
</ul></li>
</ul></li>
<li>
<a href="vcd_gateway_set-syslog-server">set-syslog-server</a></li><li>
<a href="vcd_gateway_sub-allocate-ip">sub-allocate-ip</a><ul><li>
<a href="vcd_gateway_sub-allocate-ip_add">add</a></li><li>
<a href="vcd_gateway_sub-allocate-ip_remove">remove</a></li><li>
<a href="vcd_gateway_sub-allocate-ip_update">update</a></li>
</ul></li>
<li>
<a href="vcd_gateway_sync-syslog-settings">sync-syslog-settings</a></li><li>
<a href="vcd_gateway_update">update</a></li>
</ul></li>
<li>
<a href="vcd_help">help</a></li><li>
<a href="vcd_info">info</a></li><li>
<a href="vcd_login">login</a></li><li>
<a href="vcd_logout">logout</a></li><li>
<a href="vcd_netpool">netpool</a><ul><li>
<a href="vcd_netpool_list">list</a></li>
</ul></li>
<li>
<a href="vcd_network">network</a><ul><li>
<a href="vcd_network_direct">direct</a><ul><li>
<a href="vcd_network_direct_create">create</a></li><li>
<a href="vcd_network_direct_delete">delete</a></li><li>
<a href="vcd_network_direct_list">list</a></li>
</ul></li>
<li>
<a href="vcd_network_external">external</a><ul><li>
<a href="vcd_network_external_add-ip-range">add-ip-range</a></li><li>
<a href="vcd_network_external_add-subnet">add-subnet</a></li><li>
<a href="vcd_network_external_attach-port-group">attach-port-group</a></li><li>
<a href="vcd_network_external_create">create</a></li><li>
<a href="vcd_network_external_delete">delete</a></li><li>
<a href="vcd_network_external_delete-ip-range">delete-ip-range</a></li><li>
<a href="vcd_network_external_detach-port-group">detach-port-group</a></li><li>
<a href="vcd_network_external_enable-subnet">enable-subnet</a></li><li>
<a href="vcd_network_external_info">info</a></li><li>
<a href="vcd_network_external_list">list</a></li><li>
<a href="vcd_network_external_list-allocated-ip">list-allocated-ip</a></li><li>
<a href="vcd_network_external_list-direct-org-vdc-network">list-direct-org-vdc-network</a></li><li>
<a href="vcd_network_external_list-gateway">list-gateway</a></li><li>
<a href="vcd_network_external_list-pvdc">list-pvdc</a></li><li>
<a href="vcd_network_external_list-sub-allocated-ip">list-sub-allocated-ip</a></li><li>
<a href="vcd_network_external_list-vsphere-network">list-vsphere-network</a></li><li>
<a href="vcd_network_external_update">update</a></li><li>
<a href="vcd_network_external_update-ip-range">update-ip-range</a></li>
</ul></li>
<li>
<a href="vcd_network_isolated">isolated</a><ul><li>
<a href="vcd_network_isolated_create">create</a></li><li>
<a href="vcd_network_isolated_delete">delete</a></li><li>
<a href="vcd_network_isolated_list">list</a></li>
</ul></li>
<li>
<a href="vcd_network_list">list</a></li><li>
<a href="vcd_network_routed">routed</a><ul><li>
<a href="vcd_network_routed_add-dns">add-dns</a></li><li>
<a href="vcd_network_routed_add-ip-range">add-ip-range</a></li><li>
<a href="vcd_network_routed_convert-to-distributed-interface">convert-to-distributed-interface</a></li><li>
<a href="vcd_network_routed_convert-to-internal-interface">convert-to-internal-interface</a></li><li>
<a href="vcd_network_routed_convert-to-sub-interface">convert-to-sub-interface</a></li><li>
<a href="vcd_network_routed_create">create</a></li><li>
<a href="vcd_network_routed_delete">delete</a></li><li>
<a href="vcd_network_routed_delete-ip-range">delete-ip-range</a></li><li>
<a href="vcd_network_routed_edit">edit</a></li><li>
<a href="vcd_network_routed_info">info</a></li><li>
<a href="vcd_network_routed_list">list</a></li><li>
<a href="vcd_network_routed_list-allocated-ip">list-allocated-ip</a></li><li>
<a href="vcd_network_routed_list-connected-vapps">list-connected-vapps</a></li><li>
<a href="vcd_network_routed_list-metadata">list-metadata</a></li><li>
<a href="vcd_network_routed_remove-metadata">remove-metadata</a></li><li>
<a href="vcd_network_routed_set-metadata">set-metadata</a></li><li>
<a href="vcd_network_routed_update-ip-range">update-ip-range</a></li>
</ul></li>
</ul></li>
<li>
<a href="vcd_nsxt">nsxt</a><ul><li>
<a href="vcd_nsxt_list">list</a></li><li>
<a href="vcd_nsxt_register">register</a></li><li>
<a href="vcd_nsxt_unregister">unregister</a></li>
</ul></li>
<li>
<a href="vcd_org">org</a><ul><li>
<a href="vcd_org_create">create</a></li><li>
<a href="vcd_org_delete">delete</a></li><li>
<a href="vcd_org_info">info</a></li><li>
<a href="vcd_org_list">list</a></li><li>
<a href="vcd_org_update">update</a></li><li>
<a href="vcd_org_use">use</a></li>
</ul></li>
<li>
<a href="vcd_profile">profile</a><ul><li>
<a href="vcd_profile_extension">extension</a><ul><li>
<a href="vcd_profile_extension_add">add</a></li><li>
<a href="vcd_profile_extension_delete">delete</a></li><li>
<a href="vcd_profile_extension_list">list</a></li>
</ul></li>
<li>
<a href="vcd_profile_info">info</a></li>
</ul></li>
<li>
<a href="vcd_pvdc">pvdc</a><ul><li>
<a href="vcd_pvdc_add-sp">add-sp</a></li><li>
<a href="vcd_pvdc_attach-rp">attach-rp</a></li><li>
<a href="vcd_pvdc_create">create</a></li><li>
<a href="vcd_pvdc_del-sp">del-sp</a></li><li>
<a href="vcd_pvdc_detach-rp">detach-rp</a></li><li>
<a href="vcd_pvdc_info">info</a></li><li>
<a href="vcd_pvdc_list">list</a></li><li>
<a href="vcd_pvdc_migrate-vms">migrate-vms</a></li>
</ul></li>
<li>
<a href="vcd_pwd">pwd</a></li><li>
<a href="vcd_right">right</a><ul><li>
<a href="vcd_right_add">add</a></li><li>
<a href="vcd_right_info">info</a></li><li>
<a href="vcd_right_list">list</a></li><li>
<a href="vcd_right_remove">remove</a></li>
</ul></li>
<li>
<a href="vcd_role">role</a><ul><li>
<a href="vcd_role_add-right">add-right</a></li><li>
<a href="vcd_role_create">create</a></li><li>
<a href="vcd_role_delete">delete</a></li><li>
<a href="vcd_role_info">info</a></li><li>
<a href="vcd_role_link">link</a></li><li>
<a href="vcd_role_list">list</a></li><li>
<a href="vcd_role_list-rights">list-rights</a></li><li>
<a href="vcd_role_remove-right">remove-right</a></li><li>
<a href="vcd_role_unlink">unlink</a></li>
</ul></li>
<li>
<a href="vcd_search">search</a></li><li>
<a href="vcd_system">system</a><ul><li>
<a href="vcd_system_amqp">amqp</a><ul><li>
<a href="vcd_system_amqp_info">info</a></li><li>
<a href="vcd_system_amqp_set">set</a></li><li>
<a href="vcd_system_amqp_test">test</a></li>
</ul></li>
<li>
<a href="vcd_system_extension">extension</a><ul><li>
<a href="vcd_system_extension_create">create</a></li><li>
<a href="vcd_system_extension_delete">delete</a></li><li>
<a href="vcd_system_extension_info">info</a></li><li>
<a href="vcd_system_extension_list">list</a></li>
</ul></li>
<li>
<a href="vcd_system_info">info</a></li>
</ul></li>
<li>
<a href="vcd_task">task</a><ul><li>
<a href="vcd_task_info">info</a></li><li>
<a href="vcd_task_list">list</a></li><li>
<a href="vcd_task_update">update</a></li><li>
<a href="vcd_task_wait">wait</a></li>
</ul></li>
<li>
<a href="vcd_user">user</a><ul><li>
<a href="vcd_user_create">create</a></li><li>
<a href="vcd_user_delete">delete</a></li><li>
<a href="vcd_user_list">list</a></li><li>
<a href="vcd_user_update">update</a></li>
</ul></li>
<li>
<a href="vcd_vapp">vapp</a><ul><li>
<a href="vcd_vapp_acl">acl</a><ul><li>
<a href="vcd_vapp_acl_add">add</a></li><li>
<a href="vcd_vapp_acl_list">list</a></li><li>
<a href="vcd_vapp_acl_remove">remove</a></li><li>
<a href="vcd_vapp_acl_share">share</a></li><li>
<a href="vcd_vapp_acl_unshare">unshare</a></li>
</ul></li>
<li>
<a href="vcd_vapp_add-disk">add-disk</a></li><li>
<a href="vcd_vapp_add-vm">add-vm</a></li><li>
<a href="vcd_vapp_attach">attach</a></li><li>
<a href="vcd_vapp_capture">capture</a></li><li>
<a href="vcd_vapp_change-owner">change-owner</a></li><li>
<a href="vcd_vapp_connect">connect</a></li><li>
<a href="vcd_vapp_copy">copy</a></li><li>
<a href="vcd_vapp_create">create</a></li><li>
<a href="vcd_vapp_create-snapshot">create-snapshot</a></li><li>
<a href="vcd_vapp_delete">delete</a></li><li>
<a href="vcd_vapp_deploy">deploy</a></li><li>
<a href="vcd_vapp_detach">detach</a></li><li>
<a href="vcd_vapp_discard-suspended-state">discard-suspended-state</a></li><li>
<a href="vcd_vapp_disconnect">disconnect</a></li><li>
<a href="vcd_vapp_download">download</a></li><li>
<a href="vcd_vapp_enter-maintenance-mode">enter-maintenance-mode</a></li><li>
<a href="vcd_vapp_exit-maintenance-mode">exit-maintenance-mode</a></li><li>
<a href="vcd_vapp_info">info</a></li><li>
<a href="vcd_vapp_list">list</a></li><li>
<a href="vcd_vapp_move">move</a></li><li>
<a href="vcd_vapp_network">network</a><ul><li>
<a href="vcd_vapp_network_add-dns">add-dns</a></li><li>
<a href="vcd_vapp_network_add-ip-range">add-ip-range</a></li><li>
<a href="vcd_vapp_network_connect-ovdc">connect-ovdc</a></li><li>
<a href="vcd_vapp_network_create">create</a></li><li>
<a href="vcd_vapp_network_delete">delete</a></li><li>
<a href="vcd_vapp_network_delete-ip-range">delete-ip-range</a></li><li>
<a href="vcd_vapp_network_dns-info">dns-info</a></li><li>
<a href="vcd_vapp_network_list">list</a></li><li>
<a href="vcd_vapp_network_list-allocated-ip">list-allocated-ip</a></li><li>
<a href="vcd_vapp_network_reset">reset</a></li><li>
<a href="vcd_vapp_network_services">services</a><ul><li>
<a href="vcd_vapp_network_services_dhcp">dhcp</a><ul><li>
<a href="vcd_vapp_network_services_dhcp_enable-dhcp">enable-dhcp</a></li><li>
<a href="vcd_vapp_network_services_dhcp_set">set</a></li>
</ul></li>
<li>
<a href="vcd_vapp_network_services_firewall">firewall</a><ul><li>
<a href="vcd_vapp_network_services_firewall_enable-firewall">enable-firewall</a></li>
</ul></li>
</ul></li>
<li>
<a href="vcd_vapp_network_sync-syslog-settings">sync-syslog-settings</a></li><li>
<a href="vcd_vapp_network_update">update</a></li><li>
<a href="vcd_vapp_network_update-dns">update-dns</a></li><li>
<a href="vcd_vapp_network_update-ip-range">update-ip-range</a></li>
</ul></li>
<li>
<a href="vcd_vapp_power-off">power-off</a></li><li>
<a href="vcd_vapp_power-on">power-on</a></li><li>
<a href="vcd_vapp_reboot">reboot</a></li><li>
<a href="vcd_vapp_remove-snapshot">remove-snapshot</a></li><li>
<a href="vcd_vapp_reset">reset</a></li><li>
<a href="vcd_vapp_revert-to-snapshot">revert-to-snapshot</a></li><li>
<a href="vcd_vapp_shutdown">shutdown</a></li><li>
<a href="vcd_vapp_stop">stop</a></li><li>
<a href="vcd_vapp_suspend">suspend</a></li><li>
<a href="vcd_vapp_undeploy">undeploy</a></li><li>
<a href="vcd_vapp_update">update</a></li><li>
<a href="vcd_vapp_update-lease">update-lease</a></li><li>
<a href="vcd_vapp_upgrade-virtual-hardware">upgrade-virtual-hardware</a></li><li>
<a href="vcd_vapp_use">use</a></li>
</ul></li>
<li>
<a href="vcd_vc">vc</a><ul><li>
<a href="vcd_vc_attach">attach</a></li><li>
<a href="vcd_vc_detach">detach</a></li><li>
<a href="vcd_vc_disable">disable</a></li><li>
<a href="vcd_vc_enable">enable</a></li><li>
<a href="vcd_vc_info">info</a></li><li>
<a href="vcd_vc_list">list</a></li><li>
<a href="vcd_vc_list-available-port-groups">list-available-port-groups</a></li>
</ul></li>
<li>
<a href="vcd_vdc">vdc</a><ul><li>
<a href="vcd_vdc_acl">acl</a><ul><li>
<a href="vcd_vdc_acl_add">add</a></li><li>
<a href="vcd_vdc_acl_list">list</a></li><li>
<a href="vcd_vdc_acl_remove">remove</a></li><li>
<a href="vcd_vdc_acl_share">share</a></li><li>
<a href="vcd_vdc_acl_unshare">unshare</a></li>
</ul></li>
<li>
<a href="vcd_vdc_create">create</a></li><li>
<a href="vcd_vdc_delete">delete</a></li><li>
<a href="vcd_vdc_disable">disable</a></li><li>
<a href="vcd_vdc_enable">enable</a></li><li>
<a href="vcd_vdc_info">info</a></li><li>
<a href="vcd_vdc_list">list</a></li><li>
<a href="vcd_vdc_use">use</a></li>
</ul></li>
<li>
<a href="vcd_version">version</a></li><li>
<a href="vcd_vm">vm</a><ul><li>
<a href="vcd_vm_add-nic">add-nic</a></li><li>
<a href="vcd_vm_attach-disk">attach-disk</a></li><li>
<a href="vcd_vm_check-compliance">check-compliance</a></li><li>
<a href="vcd_vm_consolidate">consolidate</a></li><li>
<a href="vcd_vm_copy">copy</a></li><li>
<a href="vcd_vm_create-snapshot">create-snapshot</a></li><li>
<a href="vcd_vm_customize-on-next-poweron">customize-on-next-poweron</a></li><li>
<a href="vcd_vm_delete">delete</a></li><li>
<a href="vcd_vm_delete-nic">delete-nic</a></li><li>
<a href="vcd_vm_deploy">deploy</a></li><li>
<a href="vcd_vm_detach-disk">detach-disk</a></li><li>
<a href="vcd_vm_discard-suspend">discard-suspend</a></li><li>
<a href="vcd_vm_eject-cd">eject-cd</a></li><li>
<a href="vcd_vm_general-setting">general-setting</a></li><li>
<a href="vcd_vm_info">info</a></li><li>
<a href="vcd_vm_insert-cd">insert-cd</a></li><li>
<a href="vcd_vm_install-vmware-tools">install-vmware-tools</a></li><li>
<a href="vcd_vm_list">list</a></li><li>
<a href="vcd_vm_list-nics">list-nics</a></li><li>
<a href="vcd_vm_list-storage-profile">list-storage-profile</a></li><li>
<a href="vcd_vm_move">move</a></li><li>
<a href="vcd_vm_power-off">power-off</a></li><li>
<a href="vcd_vm_power-on">power-on</a></li><li>
<a href="vcd_vm_reboot">reboot</a></li><li>
<a href="vcd_vm_reload-from-vc">reload-from-vc</a></li><li>
<a href="vcd_vm_reset">reset</a></li><li>
<a href="vcd_vm_revert-to-snapshot">revert-to-snapshot</a></li><li>
<a href="vcd_vm_shutdown">shutdown</a></li><li>
<a href="vcd_vm_suspend">suspend</a></li><li>
<a href="vcd_vm_undeploy">undeploy</a></li><li>
<a href="vcd_vm_update">update</a></li><li>
<a href="vcd_vm_upgrade-virtual-hardware">upgrade-virtual-hardware</a></li></ul>
</li></ul>
</li></ul>
</div>
